@@ -27,7 +27,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #ifndef basic_rfutils_h
 #define basic_rfutils_h 1
+#ifndef __cplusplus
+#include <stdbool.h>
+#endif
 #include <R.h>
+#include <Rmath.h>
+
 
 #ifdef _OPENMP
 #define DO_PARALLEL 1
@@ -37,16 +42,27 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 #endif
 
+#define MULTIMINSIZE(S) ((S) > 20)
+// #define MULTIMINSIZE(S) false
+// #define MULTIMINSIZE(S) true
+
+
 #ifndef showfree
 #define showfree !true 
-#define DOPRINT true
-// 
-// 1
-// // 1
-// // 1
 #endif
 
+
+#define DOPRINT true
+//
+// 1
+
+// // 1
+// // 1
+
+
+#ifdef __cplusplus
 extern "C" {
+#endif
   // Fortran Code by Reinhard Furrer
   void spamcsrdns_(int*, double *, int *, int*, double*);
   void spamdnscsr_(int*, int*, double *, int*, double*, int*, int*, double*);
@@ -60,7 +76,11 @@ extern "C" {
   //  void transpose_(int *, int *, double *, int * int *, double*, int*, int*);
   //  void spamback_();
   //  void spamforward();
+#ifdef __cplusplus
 }
+#endif
+
+
 
 typedef enum usr_bool {
   // NOTE: if more options are included, change ExtendedBoolean in
@@ -111,6 +131,7 @@ typedef enum usr_bool {
 #define LOG3 1.0986122886681096913952452369225257046474905578227
 #define LOG2 M_LN2
 
+
 #define EPSILON     0.00000000001
 #define EPSILON1000 0.000000001
 
@@ -118,4 +139,37 @@ typedef enum usr_bool {
 #define MAX(A,B) ((A) > (B) ? (A) : (B))
 
 
+#define ACOS(X) std::acos(X)
+#define ASIN(X) std::asin(X)
+#define ATAN(X) std::atan(X)
+#define CEIL(X) std::ceil((double) X) // keine Klammern um X!
+#define COS(X) std::cos(X)
+#define EXP(X) std::exp(X)
+#define FABS(X) std::fabs((double) X)
+#define FLOOR(X) std::floor(X)
+#define Log(X) std::log(X)
+#define POW(X, Y) std::pow((double) X, (double) Y)
+#define SIN(X) std::sin(X)
+#define SQRT(X) std::sqrt((double) X)
+#define STRCMP(A, B) std::strcmp(A, B)
+#define STRCPY(A, B) std::strcpy(A, B)
+#define STRLEN(X) std::strlen(X)
+#define STRNCMP(A, B, C) std::strncmp(A, B, C)
+#define TAN(X) std::tan(X)
+#define MEMCOPYX std::memcpy
+#define CALLOCX std::calloc
+#define MALLOCX std::malloc
+#define FREEX std::free
+#define SPRINTF std::sprintf
+
+#ifdef SCHLATHERS_MACHINE
+#define ROUND(X) round(X)
+#define TRUNC(X) trunc((double) X) // keine Klammern um X!
+#define QSORT qsort
+#else
+#define ROUND(X) round(X)
+#define TRUNC(X) trunc((double) X) // keine Klammern um X!
+#define QSORT qsort
+#endif
+
 #endif
